from .ev_base import EasyViewerMainline, EasyViewerSeunglab
from ..target_utils import is_mainline


def EasyViewer(
    target_site="seunglab",
):
    if not is_mainline(target_site) or target_site is None:
        return EasyViewerSeunglab()
    elif is_mainline(target_site):
        return EasyViewerMainline()
    else:
        raise ValueError(
            f'Unknown target: {target_site}. Must be one of "seunglab" or "spelunker/mainline"/"cave-explorer"'
        )



MAINLINE_NAMES = ["mainline", "spelunker", "cave-explorer"]
SEUNGLAB_NAMES = ["seunglab"]
default_seunglab_neuroglancer_base = "https://neuromancer-seung-import.appspot.com/"
default_mainline_neuroglancer_base = "https://spelunker.cave-explorer.org/"


def is_mainline(target_name):
    return target_name in MAINLINE_NAMES


def is_seunglab(target_name):
    return target_name in SEUNGLAB_NAMES
